activeDates property

List<DateTime>? activeDates
final

Contains the list of active dates. Only the dates in this list will be activated. In week/month granularity each entry activates the whole unit containing it.

Implementation

final List<DateTime>? activeDates;