daysCount property
Number of tiles rendered from startDate, where each tile is one granularity unit — days by default (the historical meaning), weeks or months otherwise.
Implementation
final int daysCount;
Number of tiles rendered from startDate, where each tile is one granularity unit — days by default (the historical meaning), weeks or months otherwise.
final int daysCount;