firstDayOfWeek property

int? firstDayOfWeek
final

First day of the week for DateGranularity.week, as a DateTime.monday..DateTime.sunday constant. When null it is resolved from the ambient MaterialLocalizations (Sunday for en_US; note this is independent of locale, which only formats labels). Ignored in the other granularities.

Implementation

final int? firstDayOfWeek;