showPastDates property

bool showPastDates
final

When true, the timeline also shows past dates: half of daysCount units falls before the unit containing startDate, which is treated as the anchor ("today"). The picker opens with the selected date (or the anchor) in the center of the viewport, and all DatePickerController methods scroll dates to the center instead of the leading edge.

Implementation

final bool showPastDates;