isAttached property

bool get isAttached

Whether this controller is attached to a mounted DatePicker.

All navigation methods are no-ops while detached (before the picker is built, or after it has been unmounted).

Implementation

bool get isAttached => _datePickerState != null;