gestures/tap library

Typedefs

DateChangeListener = DateSelectionCallback
Signature for a function that is called when the selected date changes.
DateSelectionCallback = void Function(DateTime selectedDate)
Signature for a function that detects when a tap has occurred.
SelectionChangeListener = void Function(List<DateTime> selectedDates)
Signature for a function that is called with the whole selection whenever it changes.