DateGranularity enum

The calendar unit each tile on the timeline represents.

Inheritance
Available extensions

Values

day → const DateGranularity

One tile per day (the default, and the pre-1.4 behavior).

week → const DateGranularity

One tile per week. Tapping a tile selects and emits the week's first day, which is determined by DatePicker.firstDayOfWeek or, when that is null, the ambient MaterialLocalizations (Sunday for en_US).

month → const DateGranularity

One tile per calendar month. Tapping a tile selects and emits the first day of the month.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DateGranularity>
A constant List of the values in this enum, in order of their declaration.