activeDates property
Contains the list of active dates. Only the dates in this list will be activated. In week/month granularity each entry activates the whole unit containing it.
Implementation
final List<DateTime>? activeDates;
Contains the list of active dates. Only the dates in this list will be activated. In week/month granularity each entry activates the whole unit containing it.
final List<DateTime>? activeDates;