inactiveDates property
Contains the list of inactive dates. All the dates defined in this List will be deactivated. In week/month granularity each entry deactivates the whole unit containing it.
Implementation
final List<DateTime>? inactiveDates;
Contains the list of inactive dates. All the dates defined in this List will be deactivated. In week/month granularity each entry deactivates the whole unit containing it.
final List<DateTime>? inactiveDates;