gestures/tap library

Typedefs

DateChangeListener = DateSelectionCallback
Signature for a function that is called when the selected date changes.
DateSelectionCallback = void Function(DateTime selectedDate)
Signature for a function that detects when a tap has occurred.