TileSelection enum
What a single date tile should paint for the current selection.
Values
- none → const TileSelection
-
Not part of the selection.
- selected → const TileSelection
-
A selected date (single/multiple mode, a pending range start, or a one-day range).
- rangeStart → const TileSelection
-
The first day of a completed range.
- rangeMiddle → const TileSelection
-
A day strictly between the endpoints of a completed range.
- rangeEnd → const TileSelection
-
The last day of a completed range.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TileSelection> - A constant List of the values in this enum, in order of their declaration.